@@ -10,5 +10,7 @@ from designer.objects.group import group
 from designer.objects.image import image
 from designer.objects.line import line
 from designer.objects.rectangle import rectangle
-from designer.objects.shape import shape
+from designer.objects.shape import shape, lines
 from designer.objects.text import text
+from designer.objects.emoji import emoji
+from designer.objects.pen import pen
\ No newline at end of file
