@@ -30,7 +30,7 @@ class DesignerGroup(DesignerObject):
         super().__init__()
 
         boxes = [
-            Rect(object._pos, object._transform_image.get_size())
+            Rect(object._pos - object._offset, object._transform_image.get_size())
             for object in objects
         ]
         if boxes:
@@ -53,7 +53,7 @@ class DesignerGroup(DesignerObject):
         self._internal_image_version: Optional[int] = None
 
         for object in objects:
-            self._internal_image._surf.blit(object._transform_image, object.pos - topleft)
+            self._internal_image._surf.blit(object._transform_image, object.pos - topleft  - object._offset)
             self._internal_image_version = 1
 
         # And draw!
